<?xml version="1.0" encoding="UTF-8"?>
<!--
This stylesheet should evolve into some convenient view of changes.xml file
-->
<xsl:stylesheet version="1.0"
    xmlns:chg="http://buildbox.sf.net/changes/2.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:output method="html"/>

  <xsl:param name="hostname"/><!-- select="'http://hostname'"/>-->
  <xsl:param name="changesPrefix" select="'http://buildbox.sf.net/changes'"/>
  <!--<xsl:param name="changesPrefix" select="'../src'"/>-->

  <xsl:variable name="groupId">
    <xsl:choose>
      <xsl:when test="*/chg:unreleased">
        <xsl:value-of select="*/chg:unreleased/@groupId"/>
      </xsl:when>
      <xsl:when test="*/chg:release">
        <xsl:value-of select="*/chg:release[1]/@groupId"/>
      </xsl:when>
      <xsl:otherwise>(unknown)</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="artifactId">
    <xsl:choose>
      <xsl:when test="*/chg:unreleased">
        <xsl:value-of select="*/chg:unreleased/@artifactId"/>
      </xsl:when>
      <xsl:when test="*/chg:release">
        <xsl:value-of select="*/chg:release[1]/@artifactId"/>
      </xsl:when>
      <xsl:otherwise>(unknown)</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="version">
    <xsl:choose>
      <xsl:when test="*/chg:unreleased">
        <xsl:value-of select="*/chg:unreleased/@version"/>
      </xsl:when>
      <xsl:when test="*/chg:release">
        <xsl:value-of select="*/chg:release[1]/@version"/>
      </xsl:when>
      <xsl:otherwise>(unknown)</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:template match="/">
    <html>
      <head>
        <title>
          <xsl:value-of select="$artifactId"/>
          <xsl:text>-</xsl:text>
          <xsl:value-of select="$version"/>
        </title>
        <link rel="stylesheet" href="{$changesPrefix}/changes.css" media="all" type="text/css"/>
      </head>

      <body>
        <h2>
          <xsl:text>History of </xsl:text>
          <a href="{$hostname}/browse/{$groupId}/{$artifactId}">
            <xsl:value-of select="$artifactId"/>
          </a>
          <b> : </b>
          <a href="{$hostname}/browse/{$groupId}/{$artifactId}/{$version}">
            <xsl:value-of select="$version"/>
          </a>
        </h2>
        <xsl:apply-templates select="*"/>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="chg:changes">
    <xsl:apply-templates select="chg:unreleased|chg:release"/>
  </xsl:template>

  <xsl:template match="chg:todos">

    <div class="head">To do:</div>
    <table class="mygrid todo" cellspacing="0">
      <xsl:for-each select="chg:todo">
        <tr>
          <td class="priority">
            <xsl:value-of select="@priority"/>
            <xsl:if test="not(@priority)">
              <br/>
            </xsl:if>
          </td>
          <td>
            <xsl:call-template name="renderComponent"/>
            <xsl:value-of select="."/>
          </td>
        </tr>
      </xsl:for-each>
    </table>
  </xsl:template>

  <xsl:template match="chg:todo">
    <li>
      <xsl:value-of select="."/>
    </li>
  </xsl:template>

  <xsl:template match="chg:unreleased">
    <div class="versionHeader">
      <div class="groupId">
        <xsl:value-of select="@groupId"/>
      </div>
      <a href="{$hostname}/browse/{@groupId}/{@artifactId}/{@version}">
        <xsl:value-of select="@artifactId"/>
        <xsl:text> : </xsl:text>
        <xsl:value-of select="@version"/>
      </a>
      <xsl:text> (unreleased)</xsl:text>
    </div>
    <xsl:apply-templates select="../chg:todos"/>
    <xsl:call-template name="allItems"/>
  </xsl:template>

  <xsl:template match="chg:release">
    <div class="versionHeader">
      <div class="groupId">
        <xsl:value-of select="@groupId"/>
      </div>
      <a class="vid" href="{$hostname}/browse/{@groupId}/{@artifactId}/{@version}">
        <xsl:value-of select="@artifactId"/>
        <xsl:text> : </xsl:text>
        <xsl:value-of select="@version"/>
      </a>
      <xsl:if test="@codename">
        <xsl:text> "</xsl:text>
        <xsl:value-of select="@codename"/>
        <xsl:text>"</xsl:text>
      </xsl:if>
      <i>
        <xsl:text> by </xsl:text>
        <a href="mailto:{@author}">
          <xsl:value-of select="@author"/>
        </a>
      </i>
    </div>
    <table class="details" cellspacing="0">
      <tr>
        <td colspan="2">
          <xsl:value-of select="translate(@timestamp,'T',' ')"/>
          <xsl:text> </xsl:text>
          <b>
            <xsl:value-of select="@author"/>
          </b>

        </td>
      </tr>
<!--
      <tr>
        <th>ID</th>
        <td>
          <xsl:call-template name="hyperArtifact"/>
        </td>
      </tr>
-->
      <tr>
        <th>Version control</th>
        <td>
          <a href="{$hostname}/vcs/{chg:vcs/@id}">
            <xsl:value-of select="chg:vcs/@id"/>
          </a>

          <b>:</b>
          <a href="{$hostname}/vcs/{chg:vcs/@id}{chg:vcs/@location}">
            <xsl:value-of select="chg:vcs/@location"/>
          </a>
        </td>
      </tr>
      <tr>
        <th>Release tag</th>
        <td>
          <xsl:value-of select="chg:vcs/@id"/>
          <b>:</b>
          <a href="{$hostname}/vcs{chg:vcs/@tag}">
            <xsl:value-of select="chg:vcs/@tag"/>
          </a>
        </td>
      </tr>
      <tr>
        <th>Build tool</th>
        <td>
          <xsl:call-template name="hyperArtifact">
            <xsl:with-param name="artifactElem" select="chg:buildtool"/>
          </xsl:call-template>
        </td>
      </tr>
    </table>
    <xsl:call-template name="allItems"/>
  </xsl:template>

  <xsl:template name="hyperArtifact">
    <xsl:param name="artifactElem" select="."/>
    <a href="{$hostname}/browse/{$artifactElem/@groupId}">
      <xsl:value-of select="$artifactElem/@groupId"/>
    </a>
    <xsl:text>:</xsl:text>
    <a class="artifactId" href="{$hostname}/browse/{$artifactElem/@groupId}/{$artifactElem/@artifactId}">
      <xsl:value-of select="$artifactElem/@artifactId"/>
    </a>
    <xsl:text>:</xsl:text>
    <a href="{$hostname}/browse/{$artifactElem/@groupId}/{$artifactElem/@artifactId}/{$artifactElem/@version}">
      <xsl:value-of select="$artifactElem/@version"/>
    </a>
  </xsl:template>

  <xsl:template name="allItems">
    <div class="head">changes</div>
    <table class="mygrid" cellspacing="0">
      <xsl:apply-templates select="chg:item"/>
      <xsl:if test="count(chg:item)=0">
        <tr>
          <td class="action"/>
          <td colspan="2">
              <i>no changes declared yet</i>
          </td>
        </tr>
      </xsl:if>
    </table>

    <xsl:for-each select="chg:upgrade">
      <div class="head">
        <xsl:text>upgrading from </xsl:text>
        <xsl:choose>
          <xsl:when test="chg:from">
            <xsl:call-template name="hyperArtifact">
              <xsl:with-param name="artifactElem" select="chg:from"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>previous version</xsl:otherwise>
        </xsl:choose>
          
      </div>
      <table class="mygrid" cellspacing="0">
        <xsl:for-each select="chg:step">
          <tr>
            <td class="step-type">
              <xsl:value-of select="@type"/>
            </td>
            <td>
              <xsl:value-of select="."/>
            </td>
          </tr>
        </xsl:for-each>
      </table>
    </xsl:for-each>
  </xsl:template>

  <xsl:template match="chg:item">
    <tr>
      <td class="action {@action}">
          <xsl:value-of select="@action"/>
        <xsl:if test="not(@action)">
          <br/>
        </xsl:if>
      </td>
      <td class="issue">
        <xsl:if test="@issue">
          <xsl:text>[#</xsl:text>
          <a href="{$hostname}/issue/{../@groupId}/{@issue}">
            <xsl:value-of select="@issue"/>
          </a>
          <xsl:text>]</xsl:text>
        </xsl:if>
        <xsl:if test="not(@issue)">
          <br/>
        </xsl:if>
      </td>
      <td class="item">
        <li class="{@action}">
          <span>
            <xsl:call-template name="renderComponent"/>
            <xsl:value-of select="."/>
            <xsl:if test="@timestamp or @author">
              <div class="metadata">
                <xsl:value-of select="translate(@timestamp,'T',' ')"/>
                <xsl:text> </xsl:text>
                <xsl:value-of select="@author"/>
              </div>
            </xsl:if>
          </span>

        </li>
      </td>
    </tr>
  </xsl:template>

  <xsl:template name="renderComponent">
    <xsl:if test="@component">
      <span class="component">
        <xsl:value-of select="@component"/>
        <xsl:text>: </xsl:text>
      </span>
    </xsl:if>
  </xsl:template>
</xsl:stylesheet>
